@@ -25,6 +25,7 @@
   @NOTATION@
  */
 
+#undef TIME_INIT
 
 /* This module takes care of handling application and library
    initialization and command line parsing */
@@ -47,11 +48,6 @@
 #include "gnome-i18n.h"
 #include "gnome-url.h"
 
-#include <gobject/gboxed.h>
-#include <gobject/gvaluearray.h>
-#include <gobject/gvaluetypes.h>
-#include <gobject/gparamspecs.h>
-
 struct _GnomeProgramPrivate {
     enum {
 	APP_UNINIT=0,
@@ -118,8 +114,6 @@ enum {
     PROP_LAST
 };
 
-static void gnome_program_class_init    (GnomeProgramClass *klass);
-static void gnome_program_instance_init (GnomeProgram      *program);
 static void gnome_program_finalize      (GObject           *object);
 
 static GQuark quark_get_prop = 0;
@@ -136,7 +130,7 @@ static guint last_property_id = PROP_LAST;
 #define	PREALLOC_MODINFOS (8)
 
 GNOME_CLASS_BOILERPLATE (GnomeProgram, gnome_program,
-			 GObject, g_object, G_TYPE_OBJECT)
+			 GObject, G_TYPE_OBJECT)
 
 static void
 gnome_program_set_property (GObject *object, guint param_id,
@@ -601,13 +595,17 @@ gnome_program_instance_init (GnomeProgram *program)
 	GnomeModuleInfo *a_module = g_ptr_array_index (program_modules, i);
 
 	if (a_module && a_module->instance_init) {
+#ifdef TIME_INIT
 	    GTimer *timer = g_timer_new ();
 	    g_timer_start (timer);
 	    g_print ("Running class_init for: %s ...", a_module->name); 
+#endif
 	    a_module->instance_init (program, a_module);
+#ifdef TIME_INIT
 	    g_timer_stop (timer);
 	    g_print ("done (%f seconds)\n", g_timer_elapsed (timer, NULL));
 	    g_timer_destroy (timer);
+#endif
 	}
     }
 }
@@ -671,7 +669,7 @@ gnome_program_finalize (GObject* object)
 	g_free (self->_priv);
 	self->_priv = NULL;
 
-	GNOME_CALL_PARENT_HANDLER (G_OBJECT_CLASS, finalize, (object));
+	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 static gpointer
@@ -1284,13 +1282,17 @@ gnome_program_preinit (GnomeProgram *program,
     /* 3. call the pre-init functions */
     for (i = 0; (a_module = g_ptr_array_index (program_modules, i)); i++) {
 	if (a_module->pre_args_parse) {
+#ifdef TIME_INIT
 	    GTimer *timer = g_timer_new ();
 	    g_timer_start (timer);
 	    g_print ("Running pre_args_parse for: %s ...", a_module->name); 
+#endif
 	    a_module->pre_args_parse (program, a_module);
+#ifdef TIME_INIT
 	    g_timer_stop (timer);
 	    g_print ("done (%f seconds)\n", g_timer_elapsed (timer, NULL));
 	    g_timer_destroy (timer);
+#endif
 	}
     }
 
@@ -1446,13 +1448,17 @@ gnome_program_postinit (GnomeProgram *program)
     /* Call post-parse functions */
     for (i = 0; (a_module = g_ptr_array_index(program_modules, i)); i++) {
 	if (a_module->post_args_parse) {
+#ifdef TIME_INIT
 	    GTimer *timer = g_timer_new ();
 	    g_timer_start (timer);
 	    g_print ("Running post_args_parse for: %s ...", a_module->name); 
+#endif
 	    a_module->post_args_parse (program, a_module);
+#ifdef TIME_INIT
 	    g_timer_stop (timer);
 	    g_print ("done (%f seconds)\n", g_timer_elapsed (timer, NULL));
 	    g_timer_destroy (timer);
+#endif
 	}
     }
 
@@ -1532,10 +1538,13 @@ gnome_program_initv (GType type,
     GnomeProgram *program;
     GnomeProgramClass *klass;
     int i;
+
+#ifdef TIME_INIT
     GTimer *global_timer = g_timer_new ();
 
     g_timer_start (global_timer);
     g_print ("Starting gnome_program_init:\n\n");
+#endif
 
     g_type_init ();
 
@@ -1594,13 +1603,17 @@ gnome_program_initv (GType type,
 	    GnomeModuleInfo *a_module = g_ptr_array_index (program_modules, i);
 
 	    if (a_module && a_module->init_pass) {
+#ifdef TIME_INIT
 	        GTimer *timer = g_timer_new ();
 	        g_timer_start (timer);
 	        g_print ("Running init_pass for: %s ...", a_module->name); 
+#endif
 		a_module->init_pass (a_module);
+#ifdef TIME_INIT
 		g_timer_stop (timer);
 		g_print ("done (%f seconds)\n", g_timer_elapsed (timer, NULL));
 		g_timer_destroy (timer);
+#endif
 	    }
 	}
 
@@ -1611,13 +1624,17 @@ gnome_program_initv (GType type,
 	    GnomeModuleInfo *a_module = g_ptr_array_index (program_modules, i);
 
 	    if (a_module && a_module->class_init) {
+#ifdef TIME_INIT
 	        GTimer *timer = g_timer_new ();
 	        g_timer_start (timer);
 	        g_print ("Running class_init for: %s ...", a_module->name); 
+#endif
 		a_module->class_init (klass, a_module);
+#ifdef TIME_INIT
 		g_timer_stop (timer);
 		g_print ("done (%f seconds)\n", g_timer_elapsed (timer, NULL));
 		g_timer_destroy (timer);
+#endif
 	    }
 	}
     } else if ( ! gnome_program_module_registered (module_info)) {
@@ -1630,13 +1647,17 @@ gnome_program_initv (GType type,
 	    GnomeModuleInfo *a_module = g_ptr_array_index (program_modules, i);
 
 	    if (a_module && a_module->init_pass) {
+#ifdef TIME_INIT
 	        GTimer *timer = g_timer_new ();
 	        g_timer_start (timer);
 	        g_print ("Running init_pass for: %s ...", a_module->name); 
+#endif
 		a_module->init_pass (a_module);
+#ifdef TIME_INIT
 		g_timer_stop (timer);
 		g_print ("done (%f seconds)\n", g_timer_elapsed (timer, NULL));
 		g_timer_destroy (timer);
+#endif
 	    }
 	}
 
@@ -1648,13 +1669,17 @@ gnome_program_initv (GType type,
 	    GnomeModuleInfo *a_module = g_ptr_array_index (program_modules, i);
 
 	    if (a_module && a_module->class_init) {
+#ifdef TIME_INIT
 	        GTimer *timer = g_timer_new ();
 	        g_timer_start (timer);
 	        g_print ("Running class_init for: %s ...", a_module->name); 
+#endif
 		a_module->class_init (klass, a_module);
+#ifdef TIME_INIT
 		g_timer_stop (timer);
 		g_print ("done (%f seconds)\n", g_timer_elapsed (timer, NULL));
 		g_timer_destroy (timer);
+#endif
 	    }
 	}
     }
@@ -1673,9 +1698,11 @@ gnome_program_initv (GType type,
     gnome_program_parse_args (program);
     gnome_program_postinit (program);
 
+#ifdef TIME_INIT
     g_timer_stop (global_timer);
     g_print ("\nGlobal init done in: %f seconds\n\n", g_timer_elapsed (global_timer, NULL));
     g_timer_destroy (global_timer);
+#endif
 
     return program;
 }
